* STUDY 1A
* Run in Tilburg University Lab week 39, 2010.

****************************************************************************************************************
* replication of tykocinski studies but with additional conditions and predictions.
* original purpose of experiment:
* to test two explanations of findings in Tykocinski 2008.
* either, lower probability judgments of medcare after insurance reminder means that people feel safe, and will thus take more risks. (i.e. moral hazard effect).
* or, the lower probability judgments reflect the intention to behave more safe in the future, which should be seen in lower risk taking intentions. (self-perception effect, i have insurance, therefore I am a careful person).

* To test this, 6 conditions.
* 1 = risk intentions (Weber, Blais, Betz, 2002, domain specific risk attitude) - reminder
* 2 = medcare (same 7 questions as in Tykocinski, 2008) - reminder                                         <- replication condition
* 3 = medcare - risk - reminder																																											
* 4 = reminder - medcare - risk                                                                                               <- replication condition
* 5 = risk - medcare - reminder																																													
* 6 = reminder - risk - medcare

* we find no support for any of these predictions - therefore only report the replication conditions.
* and run study 1b and 2
*****************************************************************************************************************

* ANALYSES FOR MAGICAL THINKING PAPER.

* select only replication conditions.

RECODE cond (2=1) (4=1) (ELSE=0) INTO tykocinski. 
EXECUTE.

USE ALL.
COMPUTE filter_$=(tykocinski = 1).
VARIABLE LABEL filter_$ 'tykocinski = 1 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

* additional coverage?

FREQUENCIES VARIABLES=aanvullend 
  /ORDER=ANALYSIS.

* mean satisfaction.

DESCRIPTIVES VARIABLES=tevreden 
  /STATISTICS=MEAN STDDEV MIN MAX.

UNIANOVA tevreden BY cond 
  /METHOD=SSTYPE(3) 
  /INTERCEPT=INCLUDE 
  /PRINT=ETASQ HOMOGENEITY DESCRIPTIVE 
  /CRITERIA=ALPHA(.05) 
  /DESIGN=cond.

* check normality of m1 to m7.
* not everything is normally distributed.
* so also report non-parametric tests.

EXAMINE VARIABLES=m1 m2 m3 m4 m5 m6 m7
  /PLOT BOXPLOT NPPLOT
  /COMPARE GROUPS
  /STATISTICS DESCRIPTIVES
  /CINTERVAL 95
  /MISSING LISTWISE
  /NOTOTAL.

* run repeated measures like tykocinski 2008 exp 1.
* no effect.


GLM m1 m2 m3 BY cond
  /WSFACTOR=factor1 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=DESCRIPTIVE ETASQ HOMOGENEITY 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=factor1 
  /DESIGN=cond.

NPAR TESTS
  /M-W= m1 m2 m3 m4 m5 m6 m7 BY cond(2 4)
  /MISSING ANALYSIS.

* analyses on all dvs.
* only effect on likelihood of war in europe. 
* not after bonferonni correction.

GLM m1 m2 m3 m4 m5 m6 m7 BY cond
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /PRINT=DESCRIPTIVE ETASQ HOMOGENEITY
  /CRITERIA=ALPHA(.05)
  /DESIGN= cond.

* AFTER 1ST ROUND OF REVIEWS, RUN POWER ANALYSES FOR EVERY STUDY.
* G*POWER REQUIRES CORRELATION BETWEEN MEASURES FOR POWER CALCULATION OF 
* REPEATED MEASURES ANOVA BETWEEN FACTORS.
* the higher the correlation between measures, the lower the power. to be conservative, we put the highest observed correlation in G*Power calculations (which is r = .538)

CORRELATIONS
  /VARIABLES=m1 m2 m3
  /PRINT=TWOTAIL NOSIG
  /MISSING=PAIRWISE.

************************************************************************************************************************
* syntax for reviewers/interested readers who wish to see what happens with risk taking measure.
* use the code below to construct the five different scales in Weber domain specific risk taking measure.
************************************************************************************************************************

RELIABILITY
  /VARIABLES=r1 r9 r17 r21 r26 r29 r36 r37
  /SCALE('social') ALL
  /MODEL=ALPHA.

COMPUTE socialrisk=(r1 +  r9 + r17 + r21 + r26 + r29 + r36 + r37) / 8.
EXECUTE.


* recreational, alpha = .808.

RELIABILITY
  /VARIABLES=r2 r6 r16 r18 r23 r33 r38 r39
  /SCALE('recreational') ALL
  /MODEL=ALPHA.

COMPUTE recreationalrisk=(r2 +r6 +r16+ r18 +r23 +r33 +r38 +r39) / 8.
EXECUTE.

* health/safety, alpha = .680 . 

RELIABILITY
  /VARIABLES=r5 r10 r15 r20 r25 r30 r35 r40
  /SCALE('health') ALL
  /MODEL=ALPHA.

COMPUTE healthrisk=(r5 +r10 +r15 +r20+ r25+ r30 +r35 +r40) / 8.
EXECUTE.

* gambling, alpha = .689 .

RELIABILITY
  /VARIABLES=r3 r11 r19 r24 r27 r32 r34 r7
  /SCALE('gambling') ALL
  /MODEL=ALPHA.

COMPUTE gamblingrisk=(r3+ r11+ r19 +r24 +r27+r32 +r34 +r7) / 8.
EXECUTE.

*ethical, alpha = .754.

RELIABILITY
  /VARIABLES=r4 r8 r12 r13 r14 r22 r28 r31
  /SCALE('ethical') ALL
  /MODEL=ALPHA.

COMPUTE ethicalrisk=(r4 +r8 +r12 +r13+ r14 +r22+ r28 +r31) / 8.
EXECUTE.

* check.

DESCRIPTIVES VARIABLES=socialrisk recreationalrisk healthrisk gamblingrisk ethicalrisk
  /STATISTICS=MEAN STDDEV VARIANCE MIN MAX KURTOSIS SKEWNESS.

